Console Server Port - Nautobot Documentation

Skip to content

# Console Server Ports

A console server is a device which provides remote access to the local consoles of connected devices. They are typically used to provide remote out-of-band access to network devices. Each console server port may be assigned a physical type.

Cables can connect console server ports to console ports or pass-through ports.

Changed in version 2.3.0

This model has been updated to support being installed in Modules. As a result, there are now two fields for assignment to a Device or Module. One of the `device` or `module` fields must be populated but not both. If a `module` is supplied, the `device` field must be null, and similarly the `module` field must be null if a `device` is supplied.